==> timemory-3.1.0rc4.tar.gz: timemory-3.1.0rc4/source/timemory/manager/macros.hpp <==
// MIT License
//
// Copyright (c) 2020, The Regents of the University of California,
// through Lawrence Berkeley National Laboratory (subject to receipt of any
// required approvals from the U.S. Dept. of Energy).  All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

/**
 * \file timemory/manager/macros.hpp
 * \brief Include the macros for manager
 */

#pragma once

#include "timemory/compat/macros.h"
#include "timemory/dll.hpp"

//======================================================================================//
//
// Define macros for manager
//
//======================================================================================//
//
#if defined(TIMEMORY_MANAGER_SOURCE)
//
#    define TIMEMORY_MANAGER_LINKAGE(...) __VA_ARGS__
//
#elif defined(TIMEMORY_USE_EXTERN) || defined(TIMEMORY_USE_MANAGER_EXTERN)
//
#    define TIMEMORY_MANAGER_LINKAGE(...) extern __VA_ARGS__
//
#else
//
#    define TIMEMORY_MANAGER_LINKAGE(...) inline __VA_ARGS__
//
#endif
//
//--------------------------------------------------------------------------------------//
//
#if defined(TIMEMORY_MANAGER_SOURCE)
#    define TIMEMORY_MANAGER_DLL tim_dll_export
#elif defined(TIMEMORY_USE_EXTERN) || defined(TIMEMORY_USE_MANAGER_EXTERN)
#    define TIMEMORY_MANAGER_DLL tim_dll_import
#else
#    define TIMEMORY_MANAGER_DLL
#endif
//
//--------------------------------------------------------------------------------------//
//

==> timemory-3.2.0.tar.gz: timemory-3.2.0/source/timemory/manager/macros.hpp <==
// MIT License
//
// Copyright (c) 2020, The Regents of the University of California,
// through Lawrence Berkeley National Laboratory (subject to receipt of any
// required approvals from the U.S. Dept. of Energy).  All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#pragma once

#include "timemory/compat/macros.h"
#include "timemory/dll.hpp"

#if defined(TIMEMORY_USE_EXTERN) && !defined(TIMEMORY_USE_MANAGER_EXTERN)
#    define TIMEMORY_USE_MANAGER_EXTERN
#endif
//
#if defined(TIMEMORY_MANAGER_SOURCE)
#    define TIMEMORY_MANAGER_LINKAGE(...) __VA_ARGS__
#    define TIMEMORY_MANAGER_LINKAGE_API
#elif defined(TIMEMORY_USE_MANAGER_EXTERN)
#    define TIMEMORY_MANAGER_LINKAGE(...) extern __VA_ARGS__
#    define TIMEMORY_MANAGER_LINKAGE_API
#else
#    define TIMEMORY_MANAGER_INLINE
#    define TIMEMORY_MANAGER_LINKAGE(...) inline __VA_ARGS__
#    define TIMEMORY_MANAGER_LINKAGE_API inline
#endif
//
